Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(97)

Unified Diff: mojo/edk/system/dispatcher.h

Issue 2088833003: Add different behavior to AwakableList for "persistent" vs "one-shot" awakables. (Closed) Base URL: https://github.com/domokit/mojo.git@work793_wait_set_4.5
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mojo/edk/system/data_pipe_producer_dispatcher.cc ('k') | mojo/edk/system/dispatcher.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mojo/edk/system/dispatcher.h
diff --git a/mojo/edk/system/dispatcher.h b/mojo/edk/system/dispatcher.h
index ea7596c4e6801ced82026ce5d94b2671f0ae9f8b..4ae4720cf040b4f7317f541ae0afa101d8771c72 100644
--- a/mojo/edk/system/dispatcher.h
+++ b/mojo/edk/system/dispatcher.h
@@ -193,9 +193,9 @@ class Dispatcher : public util::RefCountedThreadSafe<Dispatcher> {
// also be woken up when it becomes impossible for the object to ever satisfy
// |signals| with a suitable error status.
//
// If |force| is true, the awakable will be added even if |signals| is already
// satisfied or is never-satisfiable (if it is possible that some other change
// will cause it to become satisfiable again).
//
// If |signals_state| is non-null, |*signals_state| will be set to the current
// handle signals state.
@@ -209,14 +209,14 @@ class Dispatcher : public util::RefCountedThreadSafe<Dispatcher> {
// Returns:
// - |MOJO_RESULT_OK| if the awakable was added;
// - |MOJO_RESULT_ALREADY_EXISTS| if |signals| is already satisfied (if
- // |force| is true, the awakable will still be added);
+ // |persistent| is true, the awakable will still be added);
// - |MOJO_RESULT_INVALID_ARGUMENT| if the dispatcher has been closed; and
// - |MOJO_RESULT_FAILED_PRECONDITION| if it is not (or no longer) possible
// that |signals| will ever be satisfied(if |force| is true, the awakable
// will still be added).
MojoResult AddAwakable(Awakable* awakable,
uint64_t context,
- bool force,
+ bool persistent,
MojoHandleSignals signals,
HandleSignalsState* signals_state);
// Removes an awakable from this dispatcher. This will remove all instances
@@ -400,7 +400,7 @@ class Dispatcher : public util::RefCountedThreadSafe<Dispatcher> {
MOJO_SHARED_LOCKS_REQUIRED(mutex_);
virtual MojoResult AddAwakableImplNoLock(Awakable* awakable,
uint64_t context,
- bool force,
+ bool persistent,
MojoHandleSignals signals,
HandleSignalsState* signals_state)
MOJO_EXCLUSIVE_LOCKS_REQUIRED(mutex_);
@@ -193,9 +193,9 @@ class Dispatcher : public util::RefCountedThreadSafe<Dispatcher> {
// |signals| with a suitable error status.
//
- // If |force| is true, the awakable will be added even if |signals| is already
- // satisfied or is never-satisfiable (if it is possible that some other change
- // will cause it to become satisfiable again).
+ // If |persistent| is true, the awakable will be added even if |signals| is
+ // already satisfied or is never-satisfiable (if it is possible that some
+ // other change will cause it to become satisfiable again).
//
// If |signals_state| is non-null, |*signals_state| will be set to the current
@@ -209,14 +209,14 @@ class Dispatcher : public util::RefCountedThreadSafe<Dispatcher> {
// - |MOJO_RESULT_INVALID_ARGUMENT| if the dispatcher has been closed; and
// - |MOJO_RESULT_FAILED_PRECONDITION| if it is not (or no longer) possible
- // that |signals| will ever be satisfied(if |force| is true, the awakable
- // will still be added).
+ // that |signals| will ever be satisfied(if |persistent| is true, the
+ // awakable will still be added).
MojoResult AddAwakable(Awakable* awakable,
uint64_t context,
« no previous file with comments | « mojo/edk/system/data_pipe_producer_dispatcher.cc ('k') | mojo/edk/system/dispatcher.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698